# SynackAPI

This is a python package which aims to provide Synack Red Team members an easy way to interact with the Synack API.

I am in no way affiliated with Synack other than being a Synack Red Team member myself.
This project may completely break or become unusable at any time through no fault of my own.

Additionally, it is possible to use this to do stupid things that may have you suffer consequences.
Be familiar with what this tool is doing or don't use it.
I am not responsible if you get yourself in trouble.

# Contribute

With the state of the official Synack API being undocumented and me having no inside knowledge of it, this project takes a lot of work to upkeep.
Additionally, there is a good chance you are here for the mission functionality and I am directly contributing to your wallet.

If you have any ability to code and want to help improve this project, I am more than happy to consider PR's.
Otherwise, you can contribute monetarily through a number of ways found at [https://bpen.io/love](https://bpen.io/love).

# Documentation

For the most up to date information, please check out the mdBook at the link below:

https://bamhm182.github.io/SynackAPI
